package pps.core.prediction.service;

import cn.hutool.core.text.CharSequenceUtil;
import pps.cloud.base.service.BasePhotovoltaicPlantCloudService;
import pps.cloud.base.service.data.base_photovoltaic_plant.GetBasePhotovoltaicPlantCloudInput;
import pps.cloud.base.service.data.base_photovoltaic_plant.GetBasePhotovoltaicPlantCloudOutput;
import pps.cloud.system.service.SysOrganizationCloudService;
import pps.cloud.system.service.data.GetSysOrganizationViewOutput;
import pps.core.prediction.service.data.home_page.GetStationViewInput;
import pps.core.prediction.service.data.home_page.GetStationViewOutput;
import xstartup.annotation.XService;
import xstartup.annotation.XText;
import xstartup.base.XContext;
import xstartup.data.XListResult;
import xstartup.feature.api.annotation.XApiAnonymous;
import xstartup.feature.api.annotation.XApiGet;

import java.util.ArrayList;
import java.util.List;

/**
 * 首页
 *
 * @author ZWT
 * @date 2024/03/25 17:54
 */
@XText("首页模块")
@XService
public class HomePageService {

    /**
     * 首页模块--井场列表
     *
     * @param context 上下文
     * @param input   输入
     * @return {@link XListResult}<{@link GetStationViewOutput}>
     */
    @XApiAnonymous
    @XText("首页模块--井场列表")
    @XApiGet
    public XListResult<GetStationViewOutput> getStationList(XContext context, GetStationViewInput input) {
        List<GetStationViewOutput> outputs;
        String stationId = input.getStationId();
        if (CharSequenceUtil.isBlank(stationId)) {
            //查组织
            SysOrganizationCloudService service = context.getBean(SysOrganizationCloudService.class);
            XListResult<GetSysOrganizationViewOutput> result = service.getPlantList(context);
            result.throwIfFail();
            outputs = new ArrayList<>(result.getResult().size());
            result.getResult().forEach(item -> {
                GetStationViewOutput output = new GetStationViewOutput();
                output.setStationId(item.getId());
                output.setStationName(item.getOuName());
                outputs.add(output);
            });
        } else {
            //查电站
            BasePhotovoltaicPlantCloudService service = context.getBean(BasePhotovoltaicPlantCloudService.class);
            XListResult<GetBasePhotovoltaicPlantCloudOutput> result = service.getBasePhotovoltaicPlantList(context, GetBasePhotovoltaicPlantCloudInput.builder()
                    .ouId(stationId)
                    .build());
            result.throwIfFail();
            outputs = new ArrayList<>(result.getResult().size());
            result.getResult().forEach(item -> {
                GetStationViewOutput output = new GetStationViewOutput();
                output.setStationId(item.getId());
                output.setStationName(item.getStationName());
                outputs.add(GetStationViewOutput.builder()
                        .stationId(item.getId())
                        .stationName(item.getStationName())
                        .longitude(item.getLongitude())
                        .latitude(item.getLatitude())
                        .build());
            });
        }
        return XListResult.success(outputs);
    }
}